@@ -1,5 +1,5 @@
 ##
-# Copyright (c) 2010 Apple Inc. All rights reserved.
+# Copyright (c) 2010-2014 Apple Inc. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ def main():
     fig = pyplot.figure()
     ax = fig.add_subplot(111)
 
-    data = [samples for (stat, samples) in load_stats(sys.argv[1:])]
+    data = [samples for (_ignore_stat, samples) in load_stats(sys.argv[1:])]
 
     bars = []
     color = iter('rgbcmy').next
